@@ -28,10 +28,11 @@ pip install cloudcomponents.cdk-dynamodb-seeder
 
 ```python
 import * as path from 'path';
-import { Construct, Stack, StackProps, RemovalPolicy } from '@aws-cdk/core';
-import { Table, AttributeType } from '@aws-cdk/aws-dynamodb';
-import { Bucket } from '@aws-cdk/aws-s3';
 import { DynamoDBSeeder, Seeds } from '@cloudcomponents/cdk-dynamodb-seeder';
+import { Stack, StackProps, RemovalPolicy } from 'aws-cdk-lib';
+import { Table, AttributeType } from 'aws-cdk-lib/aws-dynamodb';
+import { Bucket } from 'aws-cdk-lib/aws-s3';
+import { Construct } from 'constructs';
 
 export class DynamoDBSeederStack extends Stack {
   constructor(scope: Construct, id: string, props: StackProps) {
@@ -102,27 +103,27 @@ import typing_extensions
 
 from ._jsii import *
 
-import aws_cdk.assets
+import aws_cdk
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_iam
 import aws_cdk.aws_s3
 import aws_cdk.aws_s3_assets
-import aws_cdk.core
+import constructs
 
 
 class DynamoDBSeeder(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-dynamodb-seeder.DynamoDBSeeder",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         seeds: "Seeds",
         table: aws_cdk.aws_dynamodb.ITable,
-        timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        timeout: typing.Optional[aws_cdk.Duration] = None,
     ) -> None:
         '''
         :param scope: -
@@ -147,7 +148,7 @@ class DynamoDBSeederProps:
         *,
         seeds: "Seeds",
         table: aws_cdk.aws_dynamodb.ITable,
-        timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        timeout: typing.Optional[aws_cdk.Duration] = None,
     ) -> None:
         '''
         :param seeds: -
@@ -174,7 +175,7 @@ class DynamoDBSeederProps:
         return typing.cast(aws_cdk.aws_dynamodb.ITable, result)
 
     @builtins.property
-    def timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def timeout(self) -> typing.Optional[aws_cdk.Duration]:
         '''The function execution time (in seconds) after which Lambda terminates the function.
 
         Because the execution time affects cost, set this value
@@ -183,7 +184,7 @@ class DynamoDBSeederProps:
         :default: Duration.minutes(15)
         '''
         result = self._values.get("timeout")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[aws_cdk.Duration], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -241,47 +242,41 @@ class Seeds(
         path: builtins.str,
         *,
         readers: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IGrantable]] = None,
-        source_hash: typing.Optional[builtins.str] = None,
-        exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
-        follow: typing.Optional[aws_cdk.assets.FollowMode] = None,
-        ignore_mode: typing.Optional[aws_cdk.core.IgnoreMode] = None,
-        follow_symlinks: typing.Optional[aws_cdk.core.SymlinkFollowMode] = None,
         asset_hash: typing.Optional[builtins.str] = None,
-        asset_hash_type: typing.Optional[aws_cdk.core.AssetHashType] = None,
-        bundling: typing.Optional[aws_cdk.core.BundlingOptions] = None,
+        asset_hash_type: typing.Optional[aws_cdk.AssetHashType] = None,
+        bundling: typing.Optional[aws_cdk.BundlingOptions] = None,
+        exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+        follow_symlinks: typing.Optional[aws_cdk.SymlinkFollowMode] = None,
+        ignore_mode: typing.Optional[aws_cdk.IgnoreMode] = None,
     ) -> "JsonFileSeeds":
         '''Loads the seeds from a local disk path and uploads it to s3.
 
         :param path: Path to json seeds file.
         :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
-        :param source_hash: (deprecated) Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
-        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
-        :param ignore_mode: (deprecated) The ignore behavior to use for exclude patterns. Default: - GLOB for file assets, DOCKER or GLOB for docker assets depending on whether the '
-        :param follow_symlinks: A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param asset_hash: Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
         :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
         :param bundling: Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
+        :param exclude: Glob patterns to exclude from the copy. Default: - nothing is excluded
+        :param follow_symlinks: A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
+        :param ignore_mode: The ignore behavior to use for exclude patterns. Default: IgnoreMode.GLOB
 
         :return: ``JsonFileSeeds`` associated with the specified S3 object.
         '''
         options = aws_cdk.aws_s3_assets.AssetOptions(
             readers=readers,
-            source_hash=source_hash,
-            exclude=exclude,
-            follow=follow,
-            ignore_mode=ignore_mode,
-            follow_symlinks=follow_symlinks,
             asset_hash=asset_hash,
             asset_hash_type=asset_hash_type,
             bundling=bundling,
+            exclude=exclude,
+            follow_symlinks=follow_symlinks,
+            ignore_mode=ignore_mode,
         )
 
         return typing.cast("JsonFileSeeds", jsii.sinvoke(cls, "fromJsonFile", [path, options]))
 
     @jsii.member(jsii_name="bind") # type: ignore[misc]
     @abc.abstractmethod
-    def bind(self, scope: aws_cdk.core.Construct) -> "SeedsConfig":
+    def bind(self, scope: constructs.Construct) -> "SeedsConfig":
         '''Called when the seeder is initialized to allow this object to bind to the stack.
 
         :param scope: The binding scope.
@@ -291,7 +286,7 @@ class Seeds(
 
 class _SeedsProxy(Seeds):
     @jsii.member(jsii_name="bind")
-    def bind(self, scope: aws_cdk.core.Construct) -> "SeedsConfig":
+    def bind(self, scope: constructs.Construct) -> "SeedsConfig":
         '''Called when the seeder is initialized to allow this object to bind to the stack.
 
         :param scope: The binding scope.
@@ -364,7 +359,7 @@ class InlineSeeds(
         jsii.create(self.__class__, self, [seeds])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, _scope: aws_cdk.core.Construct) -> SeedsConfig:
+    def bind(self, _scope: constructs.Construct) -> SeedsConfig:
         '''Called when the seeder is initialized to allow this object to bind to the stack.
 
         :param _scope: -
@@ -384,43 +379,37 @@ class JsonFileSeeds(
         path: builtins.str,
         *,
         readers: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IGrantable]] = None,
-        source_hash: typing.Optional[builtins.str] = None,
-        exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
-        follow: typing.Optional[aws_cdk.assets.FollowMode] = None,
-        ignore_mode: typing.Optional[aws_cdk.core.IgnoreMode] = None,
-        follow_symlinks: typing.Optional[aws_cdk.core.SymlinkFollowMode] = None,
         asset_hash: typing.Optional[builtins.str] = None,
-        asset_hash_type: typing.Optional[aws_cdk.core.AssetHashType] = None,
-        bundling: typing.Optional[aws_cdk.core.BundlingOptions] = None,
+        asset_hash_type: typing.Optional[aws_cdk.AssetHashType] = None,
+        bundling: typing.Optional[aws_cdk.BundlingOptions] = None,
+        exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+        follow_symlinks: typing.Optional[aws_cdk.SymlinkFollowMode] = None,
+        ignore_mode: typing.Optional[aws_cdk.IgnoreMode] = None,
     ) -> None:
         '''
         :param path: -
         :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
-        :param source_hash: (deprecated) Custom hash to use when identifying the specific version of the asset. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the source hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the source hash, you will need to make sure it is updated every time the source changes, or otherwise it is possible that some deployments will not be invalidated. Default: - automatically calculate source hash based on the contents of the source file or directory.
-        :param exclude: (deprecated) Glob patterns to exclude from the copy. Default: nothing is excluded
-        :param follow: (deprecated) A strategy for how to handle symlinks. Default: Never
-        :param ignore_mode: (deprecated) The ignore behavior to use for exclude patterns. Default: - GLOB for file assets, DOCKER or GLOB for docker assets depending on whether the '
-        :param follow_symlinks: A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param asset_hash: Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
         :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
         :param bundling: Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
+        :param exclude: Glob patterns to exclude from the copy. Default: - nothing is excluded
+        :param follow_symlinks: A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
+        :param ignore_mode: The ignore behavior to use for exclude patterns. Default: IgnoreMode.GLOB
         '''
         options = aws_cdk.aws_s3_assets.AssetOptions(
             readers=readers,
-            source_hash=source_hash,
-            exclude=exclude,
-            follow=follow,
-            ignore_mode=ignore_mode,
-            follow_symlinks=follow_symlinks,
             asset_hash=asset_hash,
             asset_hash_type=asset_hash_type,
             bundling=bundling,
+            exclude=exclude,
+            follow_symlinks=follow_symlinks,
+            ignore_mode=ignore_mode,
         )
 
         jsii.create(self.__class__, self, [path, options])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, scope: aws_cdk.core.Construct) -> SeedsConfig:
+    def bind(self, scope: constructs.Construct) -> SeedsConfig:
         '''Called when the seeder is initialized to allow this object to bind to the stack.
 
         :param scope: -
@@ -454,7 +443,7 @@ class S3Seeds(
         jsii.create(self.__class__, self, [bucket, key, object_version])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, _scope: aws_cdk.core.Construct) -> SeedsConfig:
+    def bind(self, _scope: constructs.Construct) -> SeedsConfig:
         '''Called when the seeder is initialized to allow this object to bind to the stack.
 
         :param _scope: -
